%* sasdrugdev_addrolemember                                                                      *;
%*                                                                                               *;
%* Adds a user or group as a member of a role in the specified organization, project, or         *;
%* analysis.                                                                                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ADDROLEMEMBER(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                          *;
%* SDD_ROLE_CONTEXT=sdd-role-context, SDD_MEMBER=sdd-member-identifier                           *;
%* <, SDD_TYPE=sdd-member-type, SDD_GROUP_CONTEXT=sdd-group-context>);                           *;
%*                                                                                               *;
%* Example Code                                                                                  *;
%* Context paths used in examples:                                                               *;
%* -  Organization: /SAS                                                                         *;
%* -  Project:      /SAS/Project1                                                                *;
%* -  Analysis:     /SAS/Project1/Analysis1                                                      *;
%*                                                                                               *;
%* 1. Add User to Role defined at Project:                                                       *;
%*    %sasdrugdev_addrolemember(sdd_path=%str(/SAS/Project1), sdd_role=%str(PrjRole1),           *;
%*    sdd_role_context=%str(/SAS/Project1),sdd_member=%str(User1), sdd_type=%str(USER));         *;
%*                                                                                               *;
%* 2. Add Group defined at Organization to Role defined at Project:                              *;
%*    %sasdrugdev_addrolemember(sdd_path=%str(/SAS/Project1), sdd_role=%str(PrjRole1),           *;
%*    sdd_role_context=%str(/SAS/Project1),sdd_member=%str(OrgGrp1), sdd_type=%str(GROUP),       *;
%*    sdd_group_context=%str(/SAS));                                                             *;
%*                                                                                               *;
%* 3. Add User to Role assigned at Project:                                                      *;
%*    %sasdrugdev_addrolemember(sdd_path=%str(/SAS/Project1), sdd_role=%str(OrgRole1),           *;
%*    sdd_role_context=%str(/SAS),sdd_member=%str(User1), sdd_type=%str(USER));                  *;
%*                                                                                               *;
%* 4. Add Group defined at Organization to Role assigned at Project:                             *;
%*    %sasdrugdev_addrolemember(sdd_path=%str(/SAS/Project1), sdd_role=%str(OrgRole1),           *;
%*    sdd_role_context=%str(/SAS),sdd_member=%str(OrgGrp1), sdd_type=%str(GROUP),                *;
%*    sdd_group_context=%str(/SAS));                                                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is assigned.                                              *;
%* @param sdd_role - required - the name of the role to add the member.                          *;
%* @param sdd_role_context - required - specifies the context in which the role is defined as a  *;
%*            path (e.g., /SAS).                                                                 *;
%* @param sdd_member required - the user ID of the user or the name of the group being added.    *;
%* @param sdd_type conditional - the type of member being added.                                 *;
%*            Values:  USER | GROUP (case-insensitive)                                           *;
%*            Default: USER                                                                      *;
%* @param sdd_group_context - conditional - specifies the context in which the group is defined  *;
%*            as a path (e.g., /SAS). This parameter is required if SDD_TYPE=GROUP. Otherwise,   *;
%*            it will be ignored.                                                                *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_addrolemember(
  sdd_path=,
  sdd_role=,
  sdd_role_context=,
  sdd_member=,
  sdd_type=USER,
  sdd_group_context=
  ) /des='Add a member to the role in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RoleService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("addMember", "%bquote(&sdd_path)", "%bquote(&sdd_role)", "%bquote(&sdd_role_context)", "%bquote(&sdd_type)", "%bquote(&sdd_member)", "%bquote(&sdd_group_context)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The &sdd_type &sdd_member has been added to &sdd_role in &sdd_path.." ;
    end;
      else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot add &sdd_type &sdd_member to &sdd_role in &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_addrolemember;
