%* sasdrugdev_getacls                                                                            *;
%*                                                                                               *;
%* Returns a SAS data set that contains the access control list for objects in the SAS Drug      *;
%* Development repository.                                                                       *;
%*                                                                                               *;
%* For container objects, both the DEFAULT and CURRENT access control lists are returned with    *;
%* the exception of analyses. For non-container objects and Analyses, only the CURRENT access    *;
%* control lists is returned.                                                                    *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETACLS(SDD_PATH=sdd-path, <SAS_DSNAME=SAS-data-set,                              *;
%* SDD_RECURSIVE=recursion-level>);                                                              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the content object in the SAS Drug Development       *;
%*            repository.  This can be either a file or a container.                             *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the access control lists specified as libref.dataset. The default     *;
%*            value is WORK.SDDGETACL. The data set contains a row for each access control       *;
%*            entry, sorted by path and aclType, and columns with the following names:           *;
%*            - name: The name of the object.                                                    *;
%*            - path: The path to the object.                                                    *;
%*            - objectType: Describes the type of the object (e.g. folder, data set, etc.)       *;
%*            - isContainer: A numeric flag that indicates whether the object is a container     *;
%*                  object (0=no, 1=yes).                                                        *;
%*            - owner: The user ID of the user who owns the object.                              *;
%*            - aclType: Will be either DEFAULT or CURRENT.  Analyses and files only have        *;
%*                  CURRENT acls.  All other containers have both DEFAULT and CURRENT acls.      *;
%*            - aclPrincipalName: If the aclPrincipalType is ACLOWNER this will be Owner.  If    *;
%*                  the aclPrincipalType is ACLMEMBERS this will be Members.  If the             *;
%*                  aclPrincipalType is USER this will be the user ID of the user.  If the       *;
%*                  aclPrincipalType is GROUP this will be the name of the group.                *;
%*            - aclPrincipalType: Specifies if the principal is a ACLOWNER, ACLMEMBERS, USER or  *;
%*                  GROUP.                                                                       *;
%*            - grpSrcCtxt: For group principals, specifies the context path where the group     *;
%*                  was defined.                                                                 *;
%*            - adminPermission: Permission to administer the object.                            *;
%*            - readPermission: Permission to read the object.                                   *;
%*            - writePropPerm: Permission to update the object properties.                       *;
%*            - writeContentPerm: Permission to update the object content.                       *;
%*            - deletePermission: Permission to delete the object.                               *;
%*                                                                                               *;
%*            Permission values are specified as follows.                                        *;
%*             1 = Allowed                                                                       *;
%*            -1 = Denied                                                                        *;
%*             0 = Not specified (Inherited)                                                     *;
%*                                                                                               *;
%* @param sdd_recursive - conditional - the level of recursion when the path is a container.     *;
%*            Valid values are 0, 1, 2, or 99 as described below. The default value is 0.  For   *;
%*            files, the value will be ignored.                                                  *;
%*                                                                                               *;
%*             0 - Returns acls for the input container only.                                    *;
%*             1 - Returns acls for the container and all objects within the container, but not  *;
%*                 sub containers.                                                               *;
%*             2 - Returns acls for the container, all objects within the container, and one     *;
%*                 level of sub containers.                                                      *;
%*            99 - Returns acls for the container and all of the sub containers and objects      *;
%*                 (traverses the entire tree).                                                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_getacls(
  sdd_path=,
  sas_dsname=work.sddGetACLs,
  sdd_recursive=0
  ) /des='Get a list of the permissions for objects in the SAS Drug Development repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %local _tempDS_
         _sddRowCount_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);
  %let _tempDS_=%str(_tempGetACL_ds_);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname(label="Created by &SYSMACRONAME"
                   keep=aclType path name objectType owner aclPrincipalType aclPrincipalName grpSrcCtxt isContainer
                        adminPermission readPermission writePropPerm writeContentPerm deletePermission ptype_sort);
    attrib returnCode               length=8;
    attrib message                  length=$200;
    attrib logMsgPrefix             length=$70;
    attrib logMsg                   length=$300;
    attrib rowCount                 length=8;
    attrib aclCount                 length=8;
    attrib aceCount                 length=8;

    attrib path                     length=$2048    label="Object Path";
    attrib name                     length=$256     label="Object Name";
    attrib objectType               length=$32      label="Object Type";    
    attrib isContainer              length=8        label="Is Object A Container?";

    attrib owner                    length=$64      label="Owner";
    attrib aclType                  length=$32      label="ACL Type";
    attrib aclPrincipalType         length=$32      label="ACL Principal Type";
    attrib aclPrincipalName         length=$256     label="ACL Principal Name";
    attrib grpSrcCtxt               length=$2048    label="Group Context Source Path";
    attrib adminPermission          length=8        label="Admin Permission";
    attrib readPermission           length=8        label="Read Permission";
    attrib writePropPerm            length=8        label="Write Properties Permission";
    attrib writeContentPerm         length=8        label="Write Content Permission";
    attrib deletePermission         length=8        label="Delete Permission";

    attrib ptype_sort               length=8        label="Temp var - sorting value";

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/AclService") ;
    declare javaobj results("com/sas/hls/macro/results/SasAclsResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getAcls", "%bquote(&sdd_path)", "%bquote(&sdd_recursive)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve access control lists from &sdd_path" ;
    end;
      else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Access control lists were returned for &sdd_path" ;
      results.callIntMethod("getAclsSize", aclCount);
      do aclRow=0 to aclCount - 1;
        results.callStringMethod("getPath", aclRow, path);
        results.callStringMethod("getName", aclRow, name);
        results.callStringMethod("getOwner", aclRow, owner);
        results.callIntMethod("getIsContainer", aclRow, isContainer);
        results.callStringMethod("getObjectType", aclRow, objectType);
        results.callStringMethod("getAclType", aclRow, aclType);

        results.callIntMethod("getAcesSize", aclRow, aceCount);
        do aceRow=0 to aceCount - 1;
          rowCount+1;
          results.callStringMethod("getAclPrincipalType", aclRow, aceRow, aclPrincipalType);
          results.callStringMethod("getAclPrincipalName", aclRow, aceRow, aclPrincipalName);
          results.callStringMethod("getGroupContextPath", aclRow, aceRow, grpSrcCtxt);
          results.callIntMethod("getReadPermission", aclRow, aceRow, readPermission);
          results.callIntMethod("getWriteContentPermission", aclRow, aceRow, writeContentPerm);
          results.callIntMethod("getWritePropertiesPermission", aclRow, aceRow, writePropPerm);
          results.callIntMethod("getDeletePermission", aclRow, aceRow, deletePermission);
          results.callIntMethod("getAdminPermission", aclRow, aceRow, adminPermission);

          if (trim(aclPrincipalType) eq "ACLOWNER") then
            ptype_sort=1;
          else if (trim(aclPrincipalType) eq "ACLMEMBERS") then
            ptype_sort=2;
          else
            ptype_sort=99;

          output;
        end;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " sdd_recursive= &sdd_recursive" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

   run;

  %let notesOption=%sysfunc(getoption(notes));
  options nonotes;

  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;

    %***********************************;
    %* Sort by path and name           *;
    %***********************************;
    proc sort data=&sas_dsname
               out=&sas_dsname (label="Created by &SYSMACRONAME");
           by path aclType ptype_sort aclPrincipalName;
    run;

    %***********************************;
    %* Cleanup                         *;
    %***********************************;
    %if (%sysfunc(exist(&_tempDS_))>0) %then
    %do;
    proc datasets library=work nolist;
      delete &_tempDS_;
      quit; run;
    %end;

    %if (%symlocal(_tempDS_)) %then
    %do;
      %symdel _tempDS_  /nowarn;
    %end;

  %end;

  proc sql;
     alter table &sas_dsname
        drop ptype_sort;
  quit;

  options &notesOption;

%mend sasdrugdev_getacls ;
