%* sasdrugdev_getallusers                                                                        *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the users defined within the     *;
%* system.                                                                                       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETALLUSERS(<,SAS_DSNAME=SAS-data-set>);                                          *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for the users specified as libref.dataset.  The default value is                   *;
%*            WORK.SDDGETALLUSERS.  The data set contains a row for each user, sorted by user    *;
%*            ID, and columns with the following names:                                          *;
%*            - userId: The unique login identifier for this account.                            *;
%*            - displayName: The display name for the account.                                   *;
%*            - firstName: The first name of the user.                                           *;
%*            - lastName: The last name of the user.                                             *;
%*            - email: The email address for this user.                                          *;
%*            - department: The business unit this user is a part of.                            *;
%*            - phone: The phone number for this user.                                           *;
%*            - isAccountActive: A numeric flag indicating whether the account is active (0=no,  *;
%*                  1=yes).                                                                      *;
%*            - isAccountLocked: A numeric flag indicating whether the account is locked (0=no,  *;
%*                  1=yes).                                                                      *;
%*            - accountActivationDate: The date this account becomes active, this value is       *;
%*                  represented in character format.                                             *;
%*            - accountDeactivationDate: The date this account becomes inactive, this value is   *;
%*                  represented in character format.                                             *;
%*            - accountLockedBy: The user ID who locked this account.                            *;
%*            - accountLockedDate: The date this account was locked, this value is represented   *;
%*                  in character format.                                                         *;
%*            - accountStatusBy: The user ID who changed the status of this account.             *;
%*            - accountStatusDate: The date the account status was last modified, this value is  *;
%*                  represented in character format.                                             *;
%*            - accountType: The type of account, valid values are INTERACTIVE and SYSTEM.       *;
%*            - lastLogin: The date of the last time this account was logged onto, this value is *;
%*                  represented in character format.                                             *;
%*            - loginAttempts: The current number of failed login attempts associated with this  *;
%*                  account.  If the number exceeds the configured threshold, this account will  *;
%*                  be locked.  This counter gets reset when a successful login occurs.          *;
%*            - loginCount: The total number of successful logins for this account.              *;
%*            - passwordCreated: The date the current password was created, this value is        *;
%*                  represented in character format.                                             *;
%*            - passwordExpiration: The date the current password expires, this value is         *;
%*                  represented in character format.                                             *;
%*            - isPasswordExpired: A numeric flag indicating whether the password has expired    *;
%*                  (0=no, 1=yes).                                                               *;
%*            - dateAccountActivation: The date this account becomes active, this value is       *;
%*                  represented in SAS DateTime format.                                          *;
%*            - dateAccountDeactivation: The date this account becomes inactive, this value is   *;
%*                  represented in SAS DateTime format.                                          *;
%*            - dateAccountLocked: The date this account was locked, this value is represented   *;
%*                  in SAS DateTime format.                                                      *;
%*            - dateAccountStatus: The date the account status was last modified, this value is  *;
%*                  represented in SAS DateTime format.                                          *;
%*            - dateLastLogin: The date of the last time this account was logged onto, this      *;
%*                  value is represented in SAS DateTime format.                                 *;
%*            - datePasswordCreated: The date the current password was created, this value is    *;
%*                  represented in SAS DateTime format.                                          *;
%*            - datePasswordExpiration: The date the current password expires, this value is     *;
%*                  represented in SAS DateTime format.                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%*                                                                                               *;
%macro sasdrugdev_getallusers(
  sas_dsname=work.sddGetAllUsers
  ) /des='Get a list of all users defined in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %local _sddRowCount_;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);
  %let _sddRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep= userId displayName firstName lastName email department phone 
                          isAccountActive accountActivationDate accountDeactivationDate 
                          isAccountLocked accountLockedBy accountLockedDate accountStatusBy accountStatusDate
                          accountType lastLogin loginAttempts loginCount 
                          passwordCreated passwordExpiration isPasswordExpired
                          dateAccountActivation dateAccountDeactivation dateAccountLocked 
                          dateAccountStatus dateLastLogin datePasswordCreated datePasswordExpiration
                          UPUSERID
  );

    attrib returnCode              length=8;
    attrib message                 length=$200;
    attrib logMsgPrefix            length=$70;
    attrib logMsg                  length=$300;
    attrib rowCount                length=8;

    attrib userId                  length=$64    label="User ID";
    attrib UPUSERID                length=$64    label="NEEDED FOR SORTING - will be dropped";
    attrib displayName             length=$128   label="Display Name";
    attrib firstName               length=$64    label="First Name";
    attrib lastName                length=$64    label="Last Name";
    attrib email                   length=$128   label="Email Address";
    attrib department              length=$128   label="Department";
    attrib phone                   length=$64    label="Phone Number";

    attrib isAccountActive         length=8      label="Is Account Active";
    attrib accountActivationDate   length=$64    label="Account Activation Date";
    attrib accountDeactivationDate length=$64    label="Account Deactivation Date";

    attrib isAccountLocked         length=8      label="Is Account Locked";
    attrib accountLockedBy         length=$64    label="Account Locked By";
    attrib accountLockedDate       length=$64    label="Account Locked Date";
    attrib accountStatusBy         length=$64    label="Account Status Last Changed By";
    attrib accountStatusDate       length=$64    label="Account Status Last Changed Date";

    attrib accountType             length=$32    label="Account Type";
    attrib lastLogin               length=$64    label="Last Login Date";
    attrib loginAttempts           length=8      label="Failed Login Attempts (Reset on Login)";
    attrib loginCount              length=8      label="Successful Logins";

    attrib passwordCreated         length=$64    label="Password Creation Date";
    attrib passwordExpiration      length=$64    label="Password Expiration Date";
    attrib isPasswordExpired       length=8      label="Is Password Expired";

    label  dateAccountActivation="Account Activation Date (SAS DateTime Format)"
           dateAccountDeactivation="Account Deactivation Date (SAS DateTime Format)"
           dateAccountLocked="Account Locked Date (SAS DateTime Format)"
           dateAccountStatus="Account Status Last Changed Date (SAS DateTime Format)"
           dateLastLogin="Last Login Date (SAS DateTime Format)"
           datePasswordCreated="Password Creation Date (SAS DateTime Format)"
           datePasswordExpiration="Password Expiration Date (SAS DateTime Format)"
    ;
    format dateAccountActivation
           dateAccountDeactivation
           dateAccountLocked
           dateAccountStatus
           dateLastLogin
           datePasswordCreated
           datePasswordExpiration datetime.
    ;

    attrib accountActivationDateSasFormat        length=$64  label="Account Activation Date: SAS Format: USED FOR FORMATTING - will be dropped";
    attrib accountDeactivationDateSasFormat      length=$64  label="Account Deactivation Date: SAS Format: USED FOR FORMATTING - will be dropped";
    attrib accountLockedDateSasFormat            length=$64  label="Account Locked Date: SAS Format: USED FOR FORMATTING - will be dropped";
    attrib accountStatusDateSasFormat            length=$64  label="Account Status Last Changed Date: SAS Format: USED FOR FORMATTING - will be dropped";
    attrib lastLoginSasFormat                    length=$64  label="Last Login Date: SAS Format: USED FOR FORMATTING - will be dropped";
    attrib passwordCreatedSasFormat              length=$64  label="Password Creation Date: SAS Format: USED FOR FORMATTING - will be dropped";
    attrib passwordExpirationSasFormat           length=$64  label="Password Expiration Date: SAS Format: USED FOR FORMATTING - will be dropped";

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService") ;
    declare javaobj results("com/sas/hls/macro/results/SasUsersResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getAllUsers", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve list of users.";
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" List of users was returned.";
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        results.callStringMethod("getAccountActivationDate", row, accountActivationDate);
        results.callStringMethod("getAccountDeactivationDate", row, accountDeactivationDate);
        results.callStringMethod("getAccountLockedBy", row, accountLockedBy);
        results.callStringMethod("getAccountLockedDate", row, accountLockedDate);
        results.callStringMethod("getAccountStatusBy", row, accountStatusBy);
        results.callStringMethod("getAccountStatusDate", row, accountStatusDate);
        results.callStringMethod("getAccountType", row, accountType);
        results.callStringMethod("getDepartment", row, department);
        results.callStringMethod("getDisplayName", row, displayName);
        results.callStringMethod("getEmail", row, email);
        results.callStringMethod("getFirstName", row, firstName);
        results.callStringMethod("getLastLogin", row, lastLogin);
        results.callStringMethod("getLastName", row, lastName);
        results.callLongMethod("getLoginAttempts", row, loginAttempts);
        results.callLongMethod("getLoginCount", row, loginCount);
        results.callStringMethod("getPasswordCreated", row, passwordCreated);
        results.callStringMethod("getPasswordExpiration", row, passwordExpiration);
        results.callStringMethod("getPhone", row, phone);
        results.callStringMethod("getUserId", row, userId);
        results.callIntMethod("isAccountActive", row, isAccountActive);
        results.callIntMethod("isAccountLocked", row, isAccountLocked);
        results.callIntMethod("isPasswordExpired", row, isPasswordExpired);

        results.callStringMethod("getAccountActivationDateSasFormat", row, accountActivationDateSasFormat);
        results.callStringMethod("getAccountDeactivationDateSasFormat", row, accountDeactivationDateSasFormat);
        results.callStringMethod("getAccountLockedDateSasFormat", row, accountLockedDateSasFormat);
        results.callStringMethod("getAccountStatusDateSasFormat", row, accountStatusDateSasFormat);
        results.callStringMethod("getLastLoginSasFormat", row, lastLoginSasFormat);
        results.callStringMethod("getPasswordCreatedSasFormat", row, passwordCreatedSasFormat);
        results.callStringMethod("getPasswordExpirationSasFormat", row, passwordExpirationSasFormat);

        UPUSERID=upcase(userId);

        dateAccountActivation = input(accountActivationDateSasFormat, datetime.);
        dateAccountDeactivation = input(accountDeactivationDateSasFormat, datetime.);
        dateAccountLocked = input(accountLockedDateSasFormat, datetime.);
        dateAccountStatus = input(accountStatusDateSasFormat, datetime.);
        dateLastLogin = input(lastLoginSasFormat, datetime.);
        datePasswordCreated = input(passwordCreatedSasFormat, datetime.);
        datePasswordExpiration = input(passwordExpirationSasFormat, datetime.);

        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    if (rowCount=0) then
      put logMsgPrefix " No users were found.";
    else
      put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %let notesOption=%sysfunc(getoption(notes));
  options nonotes;
  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
    proc sort data=&sas_dsname;
      by upuserid;
    run;
  %end;
  %***********************************;
  %* Cleanup                         *;
  %***********************************;
  proc sql;
     alter table &sas_dsname
        drop UPUSERID;
  quit;

  options &notesOption;

%mend sasdrugdev_getallusers;
