%* sasdrugdev_getchildren                                                                        *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for objects within a container in the SAS   *;
%* Drug Development repository.                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETCHILDREN(SDD_PATH=sdd-path <, SDD_RECURSIVE=recursion-level,                   *;
%* SAS_DSNAME=SAS-data-set>);                                                                    *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the container object in the SAS Drug Development     *;
%*            repository.                                                                        *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the objects specified as libref.dataset. The default value is         *;
%*            WORK.SDDGETACL. The data set contains a row for each object in the list and        *;
%*            columns with the following names.  The data set will be sorted by path.            *;
%*            - name: The name of the object.                                                    *;
%*            - path: The path of the object.                                                    *;
%*            - objectType: Describes the type of the object (e.g. folder, data set, etc.)       *;
%*            - description: The description of the object.                                      *;
%*            - isContainer: A numeric flag that indicates whether the object is a container     *;
%*                  object (0=no, 1=yes).                                                        *;
%*            - isVersioned: A numeric flag that indicates whether the object is currently       *;
%*                  versioned (0=no, 1=yes).                                                     *;
%*            - versionLabel: The label associated with this specific version.                   *;
%*            - isCheckedOut: A  numeric flag that indicates whether the object is currently     *;
%*                  checked out (0=no, 1=yes).                                                   *;
%*            - isLocked: A numeric flag that indicates whether the object is currently locked   *;
%*                  (0=no, 1=yes).                                                               *;
%*            - size: The size of the object in bytes (will be 0 for containers).                *;
%*            - contentType: The content or MIME type of object.                                 *;
%*            - createdBy: The user ID that created the object.                                  *;
%*            - created: The full date and time when the object was created. This value is       *;
%*                  represented as a String.                                                     *;
%*            - dateCreated: The date when the object was created as a SAS Datetime format.      *;
%*            - lastModifiedBy: The user ID that last modified the object.                       *;
%*            - lastModified: The date when the object was last modified.  This value is         *;
%*                  represented as a String.                                                     *;
%*            - dateLastModified: The date when the object was last modified as a SAS Datetime   *;
%*                  format.                                                                      *;
%*            - propertiesLastModifiedBy: The user ID that last modified the properties for the  *;
%*                  object.                                                                      *;
%*            - propertiesLastModified: The date when the object properties were last modified.  *;
%*                  This value is represented as a String.                                       *;
%*            - datePropertiesLastModified: The date when the object properties were last        *;
%*                  modified as a SAS Datetime format.                                           *;
%*            - state: This variable is for an Analysis or Project object only.  It indicates    *;
%*                  if the state is DEV, PROD, or CLOSED.                                        *;
%*            - stateComment: This variable is for Analysis or Project only and provides any     *;
%*                  comments attached by a user when changing the state of the project or        *;
%*                  analysis.                                                                    *;
%*            - isSigned: Indicates if the object has electronic signatures attached to it.      *;
%*                                                                                               *;
%* @param sdd_recursive - optional - the level of recursion when the path is a container.        *;
%*            Valid values are 0, 1, 2, or 99 as described below. The default value is 0.  For   *;
%*            files, the value will be ignored.                                                  *;
%*                                                                                               *;
%*             0 - Returns acls for the input container only.                                    *;
%*             1 - Returns acls for the container and all objects within the container, but not  *;
%*                 sub containers.                                                               *;
%*             2 - Returns acls for the container, all objects within the container, and one     *;
%*                 level of sub containers.                                                      *;
%*            99 - Returns acls for the container and all of the sub containers and objects      *;
%*                 (traverses the entire tree).                                                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-06-28  version 1.2 update - path length                                         *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2014-05-07  updated documentation and fixed data set processing.                     *;
%*                                                                                               *;

%macro sasdrugdev_getchildren(
  sdd_path=,
  sas_dsname=work.sddGetChildren,
  sdd_recursive=0
  ) /des='Get a list of the objects in a folder in SAS Drug Development.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %local _sddRowCount_;

  %let _sddRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=path name description objectType isContainer 
                         description versionLabel isVersioned isCheckedOut isLocked isSigned size contentType  
                         createdBy created dateCreated 
                         lastModifiedBy lastModified dateLastModified 
                         propertiesLastModifiedBy propertiesLastModified datePropertiesLastModified
                         state stateComment isSigned uppath);

    attrib returnCode                length=8 
           message                   length=$200 
           logMsgPrefix              length=$70 
           logMsg                    length=$300 
           rowCount                  length=8 

           path                      length=$2048    label="Object Path" 
           name                      length=$256     label="Object Name" 
           objectType                length=$32      label="Object Type" 
           isContainer               length=8        label="Is Object A Container?" 

           description               length=$512     label="Description" 
           versionLabel              length=$32      label="Version Number" 
           isVersioned               length=8        label="Is File Versioned" 
           isCheckedOut              length=8        label="Is File Checked out" 
           isLocked                  length=8        label="Is File Locked" 
           isSigned                  length=8        label="Is File Signed" 
           size                      length=8        label="Size In Bytes" 
           contentType               length=$32      label="Content Type" 

           createdBy                 length=$64      label="Userid that created the object" 
           created                   length=$64      label="Object Creation Date" 
           dateCreated                               label="Date the object was created (SAS DateTime Format)"

           lastModifiedBy            length=$64      label="Userid that last modified the object content" 
           lastModified              length=$64      label="Last Content Modification Date" 
           dateLastModified                          label="Date the object's content was last modified (SAS DateTime Format)"

           propertiesLastModifiedBy  length=$64      label="Userid that last modified the object properties" 
           propertiesLastModified    length=$64      label="Last Properties Modification Date" 
           datePropertiesLastModified                     label="Date the object's properties were last modified (SAS DateTime Format)" 

           state                     length=$64      label="State of an Analysis or Project"  
           stateComment              length=$512     label="Comment associated with the state of an Analysis or Project" 

           createdTempSAS            length=$64      label="TEMPORARY - WILL BE DROPPED"
           propertiesLastModifiedTempSAS  length=$64      label="TEMPORARY - WILL BE DROPPED"
           lastModifiedTempSAS       length=$64      label="TEMPORARY - WILL BE DROPPED"
           uppath                    length=$2048    label="TEMPORARY - WILL BE DROPPED"
    ;

    format dateCreated
           dateLastModified
           datePropertiesLastModified datetime. 
    ;

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService") ;
    declare javaobj results("com/sas/hls/macro/results/SasResourcesResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getChildren", "%bquote(&sdd_path)", "%bquote(&sdd_recursive)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Could not retrieve list of objects from %bquote(&sdd_path)" ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Returned a list of objects in %bquote(&sdd_path)";
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        results.callStringMethod("getPath", row, path);
        results.callStringMethod("getName", row, name);
        results.callStringMethod("getDescription", row, description);
        results.callStringMethod("getVersionLabel", row, versionLabel);
        results.callIntMethod("isContainer", row, isContainer);
        results.callIntMethod("isVersioned", row, isVersioned);
        results.callIntMethod("isCheckedOut", row, isCheckedOut);
        results.callIntMethod("isLocked", row, isLocked);
        results.callIntMethod("isSigned", row, isSigned);
        results.callLongMethod("getSize", row, size);
        results.callStringMethod("getContentType", row, contentType);
        results.callStringMethod("getObjectType", row, objectType);
        results.callStringMethod("getCreated", row, created);
        results.callStringMethod("getCreatedBy", row, createdBy);
        results.callStringMethod("getLastModified", row, lastModified);
        results.callStringMethod("getLastModifiedBy", row, lastModifiedBy);
        results.callStringMethod("getPropertiesLastModified", row, propertiesLastModified);
        results.callStringMethod("getPropertiesLastModifiedBy", row, propertiesLastModifiedBy);
        results.callStringMethod("getState", row, state);
        results.callStringMethod("getStateComment", row, stateComment);

        results.callStringMethod("getCreatedSasFormat", row, createdTempSas);
        results.callStringMethod("getLastModifiedSasFormat", row, lastModifiedTempSas);
        results.callStringMethod("getPropertiesLastModifiedSasFormat", row, propertiesLastModifiedTempSAS);

        dateCreated=input(createdTempSAS, datetime.);
        dateLastModified=input(lastModifiedTempSas, datetime.);
        datePropertiesLastModified=input(propertiesLastModifiedTempSAS, datetime.);

        uppath=upcase(path) ;
        uppath=translate(uppath,'1','_');

        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
      if (rowCount=0) then
        put logMsgPrefix " No children were found.";
      else
         put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " sdd_recursive= &sdd_recursive" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %let notesOption=%sysfunc(getoption(notes));
  options nonotes;

  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
    proc sort data=&sas_dsname;
      by uppath;
    run;
  %end;
  %***********************************;
  %* Cleanup                         *;
  %***********************************;
  proc sql;
     alter table &sas_dsname
        drop uppath;
  quit;

  options &notesOption;

%mend sasdrugdev_getchildren ;
