%* sasdrugdev_getgroups                                                                          *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the groups defined within a      *;
%* context object within the specified organization, project, or analysis.                       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETGROUPS(SDD_PATH=sdd-path <, SAS_DSNAME=SAS-data-set>);                         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the groups are defined.                                            *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for the groups specified as libref.dataset. The default value is WORK.SDDGETGROUPS.*;
%*            The data set contains a row for each member and columns with the following names.  *;
%*            The data set will be sorted by group name.                                         *;
%*            - contextPath: The path of the context object in the repository.                   *;
%*            - name: The name of the group.                                                     *;
%*            - description: The group description.                                              *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;
%macro sasdrugdev_getgroups(
  sdd_path=,
  sas_dsname=work.sddGetGroups
  ) /des='Get a list of groups defined in an SDD context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %local _sddRowCount_;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);
  %let _sddRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=contextPath name description);
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib rowCount        length=8;
    
    attrib contextPath     length=$2048    label="Context Path" ;
    attrib name            length=$256     label="Group Name";
    attrib description     length=$128     label="Group Description";

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/GroupService") ;
    declare javaobj results("com/sas/hls/macro/results/SasGroupsResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getGroups", "%bquote(&sdd_path)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve list of groups in &sdd_path..";
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" List of groups was returned for &sdd_path.." ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        contextPath="&sdd_path";
        results.callStringMethod("getName", row, name);
        results.callStringMethod("getDescription", row, description);
        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    if (rowCount=0) then
      put logMsgPrefix " No groups were found.";
    else
      put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
    %let notesOption=%sysfunc(getoption(notes));
    options nonotes;
    proc sort data=&sas_dsname;
      by name;
    run;
    options &notesOption;
  %end;

%mend sasdrugdev_getgroups;
