%* sasdrugdev_getjoboutputs                                                                      *;
%*                                                                                               *;
%* Returns a SAS data set containing metadata for the outputs for the specified job in the SAS   *;
%* Drug Development repository.                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETJOBOUTPUTS(SDD_PATH=sdd-path <SDD_VERSION=sdd-version,                         *;
%*                  SAS_DSNAME=SAS-data-set>);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the job.                                             *;
%* @param sdd_version - optional - the version of the job. If not specified, the latest version  *;
%*            will be used.                                                                      *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the outputs specified as libref.dataset. The default value is         *;
%*            WORK.SDDGETJOBOUTPUTS. The data set contains a row for each job output and columns *;
%*            with the following names.  The data set will retain the order of the outputs.      *;
%*            - jobPath: The path of the job.                                                    *;
%*            - jobVersion: The job version.                                                     *;
%*            - outputPath: The path of the output location.                                     *;
%*            - outputIncludesSubFolders: A flag indicating whether or not the subfolders of an  *;
%*              output container are to be included during job execution.                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-22  initial coding.                                                          *;
%*                                                                                               *;

%macro sasdrugdev_getjoboutputs(
   sdd_path=,
   sdd_version=,
   sas_dsname=work.sddGetJobOutputs  
   ) /des='Get a list of the outputs for a job.';

   %****************************************;
   %* Initialize macro variables           *;
   %****************************************;
   %global _sddMsg_
           _sddRC_
   ;

   %let _sddRC_ =%str(-999);
   %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

   %**********************************************;
   %* Start the datastep to call the java code   *;
   %**********************************************;
   data &sas_dsname (label="Created by &SYSMACRONAME"
                     keep=jobPath jobVersion outputPath outputIncludesSubFolders
   );

   attrib 
          returnCode      length=8 
          message         length=$200 
          logMsgPrefix    length=$70 
          logMsg          length=$300 
          rowCount        length=8 

          jobPath         length=$2048     label="Job Path" 
          jobVersion      length=$32       label="Job Version" 

          outputPath        length=$2048     label="Output Path" 
          outputIncludesSubFolders length=8  label="Include Output Container SubFolders"

          includeSubFolders length=$5       label="FOR INTERNAL PROCESSING ONLY.  WILL BE DROPPED." 
   ;

   rowCount=0;

   %***********************************;
   %* Declare the java objects        *;
   %***********************************;
   declare javaobj srv("com/sas/hls/macro/service/JobService") ;
   declare javaobj results("com/sas/hls/macro/results/SasResourceSpecificationResult");

   %***********************************;
   %* Attempt the operation           *:
   %***********************************;
   srv.callStaticVoidMethod("getJobOutputs", "%bquote(&sdd_path)", "%bquote(&sdd_version)", results) ;

   %***********************************;
   %* Retrieve the results            *;
   %***********************************;
   results.callIntMethod("getReturnCode", returnCode);
   results.callStringMethod("getReturnMessage", message);

   %***********************************;
   %* Process the results             *;
   %***********************************;
   if (returnCode ne 0) then
   do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve outputs for job &sdd_path, version &sdd_version." ;
   end;
   else
   do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Outputs were returned for job &sdd_path" ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
         jobPath="&sdd_path";
         jobVersion="&sdd_version";
         results.callStringMethod("getPath", row, outputPath);
         results.callStringMethod("getIncludeSubFolders", row, includeSubFolders);
         outputIncludesSubFolders=input(includeSubFolders,best.);
         output;
      end;
   end;

   %***********************************;
   %* Print messages in log           *;
   %***********************************;
   put;
   put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
   put logMsgPrefix " " logMsg;
   if (rowCount=0) then
      put logMsgPrefix " No outputs were found.";
   else
      put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
   put logMsgPrefix " _sddMsg_= " message ;
   put logMsgPrefix " _sddRC_= " returnCode ;
   put;

   %***********************************;
   %* Set the macro variables         *;
   %***********************************;
   call symputx("_sddRC_", returnCode);
   call symputx("_sddMsg_", message);

   run;

%mend sasdrugdev_getjoboutputs;
