%* sasdrugdev_getjobparameters                                                                   *;
%*                                                                                               *;
%* Returns a SAS data set containing job parameter metadata for the specified job.               *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETJOBPARAMETERS(SDD_PATH=sdd-path <SDD_VERSION=sdd-version,                      *;
%*                  SAS_DSNAME=SAS-data-set>);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the job.                                             *;
%* @param sdd_version - optional - the version of the job. If not specified, the latest version  *;
%*            will be used.                                                                      *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the parameters specified as libref.dataset. The default value is      *;
%*            WORK.SDDGETJOBPARAMETERS. The data set contains a row for each job parameter       *;
%*            and columns with the following names.  The data set will retain the job parameter  *;
%*            order.                                                                             *;
%*            - jobPath: The path of the job.                                                    *;
%*            - jobVersion: The job version.                                                     *;
%*            - name: The name of the parameter.                                                 *;
%*            - label: The parameter label.                                                      *;
%*            - type: The parameter type.  Values are CHARACTER, CHARACTER_MASKED, NUMERIC,      *;
%*                  DATE, FILE, or FOLDER.                                                       *;
%*            - defaultValue: the default value for the parameter. Dates are returned in SAS     *;
%*                  datetime format.                                                             *;
%*            - fileVersion: the file version to be used if the parameter is of type FILE.       *;
%*                  A blank value means that either the file is not versioned or the file is     *;
%*                  versioned but no version was selected.                                       *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-11  initial coding.                                                          *;
%*                                                                                               *;

%macro sasdrugdev_getjobparameters(
   sdd_path=,
   sdd_version=,
   sas_dsname=work.sddGetJobParameters  
   ) /des='Get a list of the parameters for a job.';

   %****************************************;
   %* Initialize macro variables           *;
   %****************************************;
   %global _sddMsg_
           _sddRC_
   ;

   %let _sddRC_ =%str(-999);
   %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

   %local _sddRowCount_;

   %let _sddRowCount_=0;

   %**********************************************;
   %* Start the datastep to call the java code   *;
   %**********************************************;
   data &sas_dsname (label="Created by &SYSMACRONAME"
                     keep=jobPath jobVersion name label type defaultValue fileVersion
   );

   attrib 
          returnCode      length=8 
          message         length=$200 
          logMsgPrefix    length=$70 
          logMsg          length=$300 
          rowCount        length=8 

          jobPath         length=$2048     label="Job Path" 
          jobVersion      length=$32       label="Job Version" 
          name            length=$256      label="Parameter Name" 
          label           length=$256      label="Parameter Label" 
          type            length=$32       label="Parameter Type" 
          defaultValue    length=$2048     label="Parameter Default Value" 
          fileVersion     length=$32       label="File Version if File Type" 
   ;


   rowCount=0;

   %***********************************;
   %* Declare the java objects        *;
   %***********************************;
   declare javaobj srv("com/sas/hls/macro/service/JobService") ;
   declare javaobj results("com/sas/hls/macro/results/SasJobParametersResult");

   %***********************************;
   %* Attempt the operation           *:
   %***********************************;
   srv.callStaticVoidMethod("getJobParameters", "%bquote(&sdd_path)", "%bquote(&sdd_version)", results) ;

   %***********************************;
   %* Retrieve the results            *;
   %***********************************;
   results.callIntMethod("getReturnCode", returnCode);
   results.callStringMethod("getReturnMessage", message);

   %***********************************;
   %* Process the results             *;
   %***********************************;
   if (returnCode ne 0) then
   do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve parameters for job &sdd_path, version &sdd_version." ;
   end;
   else
   do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Parameters were returned for job &sdd_path" ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
         jobPath="&sdd_path";
         jobVersion="&sdd_version";
         results.callStringMethod("getName", row, name);
         results.callStringMethod("getLabel", row, label);
         results.callStringMethod("getType", row, type);
         results.callStringMethod("getDefaultValue", row, defaultValue);
         results.callStringMethod("getFileVersion", row, fileVersion);
         output;
      end;
   end;

   %***********************************;
   %* Print messages in log           *;
   %***********************************;
   put;
   put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
   put logMsgPrefix " " logMsg;
   if (rowCount=0) then
      put logMsgPrefix " No parameters were found.";
   else
      put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
   put logMsgPrefix " _sddMsg_= " message ;
   put logMsgPrefix " _sddRC_= " returnCode ;
   put;

   %***********************************;
   %* Set the macro variables         *;
   %***********************************;
   call symputx("_sddRC_", returnCode);
   call symputx("_sddMsg_", message);
   call symputx("_sddRowCount_", rowCount);

   run;

%mend sasdrugdev_getjobparameters;
