%* sasdrugdev_getroles                                                                           *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the roles defined and, if        *;
%* specified, inherited within the specified organization, project, or analysis.                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETROLES(SDD_PATH=sdd-path <,SAS_DSNAME=SAS-data-set,                             *;
%* SDD_GETINHERITED=inheritance-flag>);                                                          *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the roles exist.                                                   *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the roles specified as libref.dataset. The default value is           *;
%*            WORK.SDDGETROLES. The data set contains a row for each role in the context object  *;
%*            as well as columns with the following names.  The data set will be sorted by role  *;
%*            name.                                                                              *;
%*            - path: The path of the context object.                                            *;
%*            - name: The name of the role.                                                      *;
%*            - description: The role description.                                               *;
%*            - roleSrcCtxt: The context in which the of role was defined.                       *;
%*            - isInherited: A flag indicating whether or not the role is inherited. The valid   *;
%*                  values are 0 and 1.  This variable is not included if SDD_GETINHERITED is    *;
%*                  not valid or set to 0.                                                       *;
%* @param sdd_getinherited - optional -  indicates whether or not to include inherited roles.    *;
%*            The valid values are 0 and 1 to exclude or include inherited roles respectively.   *;
%*            The default is 1.                                                                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_getroles(
  sdd_path=,
  sas_dsname=work.sddGetRoles,
  sdd_getInherited=1
  ) /des='Get a list of roles in a SAS Drug Development context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %local _sddRowCount_;

  %let _sddRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=contextPath name description roleSrcCtxt
    %if (&sdd_getInherited eq %str(1)) %then
    %do;
        isInherited
    %end;
  );
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib rowCount        length=8;
    
    attrib contextPath     length=$2048     label="Context Path" ;
    attrib name            length=$256      label="Role Name";
    attrib description     length=$128      label="Role Description";
    attrib roleSrcCtxt     length=$2048     label="Role Context Source Path";

    %if (&sdd_getInherited eq %str(1)) %then
    %do;
      attrib isInherited   length=8         label="Is role inherited in current context: 0 or 1";
    %end;

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RoleService") ;
    declare javaobj results("com/sas/hls/macro/results/SasRolesResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getRoles", "%bquote(&sdd_path)", "%bquote(&sdd_getInherited)", results) ;

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve roles for &sdd_path" ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Roles were returned for &sdd_path" ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        contextPath="&sdd_path";
        results.callStringMethod("getContextPath", row, roleSrcCtxt);
        results.callStringMethod("getName", row, name);
        results.callStringMethod("getDescription", row, description);
        %if (&sdd_getInherited eq %str(1)) %then
        %do;
          results.callIntMethod("isInherited", row, isInherited);
        %end;
          output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
      if (rowCount=0) then
          put logMsgPrefix " No roles were found.";
     else
         put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %***********************************;
  %* Sort by name                    *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
    %let notesOption=%sysfunc(getoption(notes));
    options nonotes;
    proc sort data=&sas_dsname;
      by name;
    run;
    options &notesOption;
  %end;


%mend sasdrugdev_getroles;
