%* sasdrugdev_getsubmissionstatus                                                                *;
%*                                                                                               *;
%* Determines the status of a SAS Drug Development repository job submission.                    *;
%*                                                                                               *;
%* The SAS macro variable _sddJobSubmissionStatus_ is set to the status value. The values are    *;
%* NOT_DETERMINED, NOT_STARTED, STARTED, COMPLETED.                                              *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETSUBMISSIONSTATUS(SDD_JOBSUBMISSION_ID=job-submission-id);                      *; 
%*           <, SDD_VERSION=sdd-version> );                                                      *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddJobSubmissionStatus_ indicates the job submission status.                         *;
%*                                                                                               *;
%* @param sdd_jobsubmission_id - required - the submission identifier returned from the          *;
%*         sasdrugdev_submitjob macro.                                                           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-07  initial code                                                             *;
%*                                                                                               *;

%macro sasdrugdev_getsubmissionstatus(
  sdd_jobsubmission_id=
  ) /des='What is the submission status of SAS Drug Development job?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddJobSubmissionStatus_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib status          length=$25;

    status="";

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/JobService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticStringMethod("getJobSubmissionStatus", "%bquote(&sdd_jobsubmission_id)", results, status);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine submission status for identifier: &sdd_jobsubmission_id.." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Returned submission status: &sdd_jobsubmission_id.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddJobSubmissionStatus_= " status;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddJobSubmissionStatus_", strip(status) ) ;

  run;

%mend sasdrugdev_getsubmissionstatus;
