%* sasdrugdev_getusergroups                                                                      *;
%*                                                                                               *;
%* Returns a SAS data set containing metadata for each of the groups in which the specified      *;
%* user is a member.                                                                             *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETUSERGROUPS(SDD_USERID=sdd-userid <, SAS_DSNAME=SAS-data-set>);                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @param sdd_userid - required - the user ID of the user for which groups will be retrieved.    *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the groups specified as libref.dataset. The default value is          *;
%*            WORK.SDDGETUSERGROUPS. The data set contains a row for each group and columns      *;
%*            with the following names.  The data set will be sorted by group name and           *;
%*            group context path.                                                                *;
%*            - userId: The user ID of the user.                                                 *;
%*            - name: The name of the group.                                                     *;
%*            - description: The description of the group.                                       *;
%*            - grpSrcCtxt: The context path where the group was defined.                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-03-20  initial coding                                                           *;
%*                                                                                               *;

%macro sasdrugdev_getusergroups(
  sdd_userid=,  
  sas_dsname=work.sddGetUserGroups
  ) /des='Get a list of the groups in which a user is a member.';


  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %local _sddRowCount_ notesOption;

  %let _sddRowCount_=0;

  %**********************************************;
  %*  Start the datastep to call the java code  *;
  %**********************************************;
  data &sas_dsname (
          label="Created by &SYSMACRONAME"
          keep=userId name description grpSrcCtxt
          );
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib rowCount        length=8;
    
    attrib userId          length=$256      label="User Id";    
    attrib name            length=$256      label="Group Name";
    attrib description     length=$128      label="Group Description";
    attrib grpSrcCtxt      length=$2048     label="Group Context Source Path";

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/GroupService");
    declare javaobj results("com/sas/hls/macro/results/SasPrincipalsResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getUserGroups", "%bquote(&sdd_userid)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve groups for &sdd_userid." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Operation to retrieve groups was successful for &sdd_userid." ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        userId="&sdd_userid";	
        results.callStringMethod("getName", row, name);
        results.callStringMethod("getDescription", row, description);
        results.callStringMethod("getContextPath", row, grpSrcCtxt);
        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));	
    put logMsgPrefix " " logMsg;
      if (rowCount=0) then
          put logMsgPrefix " No groups were found.";
      else
         put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
   %let notesOption=%sysfunc(getoption(notes));
    options nonotes;
    proc sort data=&sas_dsname;
      by name grpSrcCtxt;
    run;
    options &notesOption;
  %end;

%mend sasdrugdev_getusergroups;
