%* sasdrugdev_groupexists                                                                        *;
%*                                                                                               *;
%* Determines whether a group is defined for the specified context.                              *;
%*                                                                                               *;
%* The macro variable _sddGroupExists_ will be set to 1 if the group exists, 0 if it does not.   *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GROUPEXISTS (SDD_PATH=sdd-path, SDD_GROUP=sdd- name);                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddGroupExists_ indicates if the group exists in the context.                        *;
%*                                                                                               *;
%* @param sdd_path - required -  the path of the context object.                                 *;
%* @param sdd_group - required - the name of the group.                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_groupexists(
  sdd_path=,
  sdd_group=
  ) /des='Is the group defined in the context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddGroupExists_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib exists          length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/GroupService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("exists", "%bquote(&sdd_path)", "%bquote(&sdd_group)", results, exists);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine the existence of group &sdd_group in &sdd_path.." ;
      exists=-1;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (exists) then
      do;
        logMsg=" The group &sdd_group was found in &sdd_path.";
      end;
      else
      do;
        logMsg=" The group &sdd_group was not found in &sdd_path.";
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddGroupExists_= " exists;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddGroupExists_", exists) ;

  run;

%mend sasdrugdev_groupexists ;
