%* sasdrugdev_isuserprivilege                                                                    *;
%*                                                                                               *;
%* Determines whether a global privilege is assigned to a user.                                  *;
%*                                                                                               *;
%* The SAS macro variable _sddIsUserPrivilege_ is set to a value of 1 when the privilege is      *;
%* assigned, 0 if it is not.                                                                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISUSERPRIVILEGE(SDD_USERID=sdd-userid, SDD_PRIVILEGE=sdd-privilege-id);           *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsUserPrivilege_ indicates if the privilege is assigned to the user.              *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID to check.                                          *;
%* @param sdd_privilege - required - the identifier of the global privilege to check.            *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_isuserprivilege(
  sdd_userid=,
  sdd_privilege=
  ) /des='Is the global privilege assigned to the specified user?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsUserPrivilege_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib hasPrivilege    length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/PrivilegeService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("hasPrivilege", "%bquote(&sdd_userid)", "%bquote(&sdd_privilege)", results, hasPrivilege);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine if &sdd_privilege is assigned to the user &sdd_userid..";
      hasPrivilege=-1;
    end;
      else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (hasPrivilege) then
      do;
        logMsg=" &sdd_privilege is assigned to the user &sdd_userid.." ;
      end;
      else
      do;
        logMsg=" &sdd_privilege is not assigned to the user &sdd_userid.." ;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddIsUserPrivilege_= " hasPrivilege;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddIsUserPrivilege_", hasPrivilege);

  run;

%mend sasdrugdev_isuserprivilege ;
