%* sasdrugdev_isversioned                                                                        *;
%*                                                                                               *;
%* Determines whether a SAS Drug Development repository object has versioning enabled.           *;
%*                                                                                               *;
%* The SAS macro variable _sddIsVersioned_ is set to a value of 1 when the object is versioned,  *;
%* 0 if it is not.                                                                               *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISVERSIONED(SDD_PATH=sdd-path);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsVersioned_ indicates if the object is versioned or not.                         *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file.                                            *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_isversioned(
  sdd_path=
  ) /des='Does the file in the repository have versioning enabled?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsVersioned_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib isVersioned     length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("isVersioned", "%bquote(&sdd_path)", results, isVersioned);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine if the item is versioned: &sdd_path." ;
      isVersioned=-1;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (isVersioned) then
      do;
        logMsg=" The item is versioned: &sdd_path.";
      end;
      else
      do;
        logMsg=" The item is not versioned: &sdd_path.";
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddIsVersioned_= " isVersioned;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddIsVersioned_", isVersioned) ;

  run;

%mend sasdrugdev_isversioned ;
