%* sasdrugdev_logout                                                                             *;
%*                                                                                               *;
%* Closes an open connection to SAS Drug Development.                                            *;
%*                                                                                               *;
%* This macro is only used when running the macros from a PC SAS session. This should be the     *;
%* last macro you call in any program.                                                           *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_LOGOUT();                                                                         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-06-26  version 1.2 update - trusted session                                     *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_logout(
  ) /des='Terminate the connection to SAS Drug Development.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************
  %global _sddMsg_
          _sddRC_
  ;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/SessionService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("logout", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The macro variables will be deleted: _SDDRC_ _SDDMSG_" ;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Unable to close connection." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

  %***********************************;
  %* Macro variable cleanup          *;
  %***********************************;

  %if (&_sddRC_ ne 0) %then %return;

  *retain original value for options and then turn source off;
  %let sourceOption=%sysfunc(getoption(source));
  %let notesOption=%sysfunc(getoption(notes));
  options nosource nonotes;

  data mvarstable;
     set sashelp.vmacro;
  run;
  data _null_;
     set mvarstable;
     pos=index(name,'_SDD');
     if (pos=1);
     message="Deleting macro variable " || strip(name) || " from scope " || strip(scope) || ".";
     put message;
     call execute('%symdel ' || strip(name) || '; ');
  run;
  * reset options;
  options &sourceOption &notesOption;

%mend sasdrugdev_logout ;
