%* sasdrugdev_syncfiletoworkspace                                                                *;
%*                                                                                               *;
%* Gets the version of the SAS Drug Development from the repository file to the workspace.       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_SYNCFILETOWORKSPACE(SDD_PATH=sdd-path, SDD_VERSION=sdd-version>);                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file within the SAS Drug Development repository  *;
%*            to download.                                                                       *;
%* @param sdd_version - conditional - specifies the version of the file to be synchronized if    *;
%*            the file is versioned.  If the file is versioned and a version is specified the    *;
%*            value must be in the valid format including a decimal point such as 1.0 or 4.2.    *;
%*            If the file is versioned and no version is specified the latest version is         *;
%*            downloaded.  If the file is unversioned and a version is specified, the value will *;
%*            be ignored.                                                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-07 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_syncfiletoworkspace(
  sdd_path=,
  sdd_version=
  ) /des='Get latest or specific version of a SAS Drug Development repository file to the workspace.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode       length=8
           message          length=$200
           logMsgPrefix     length=$70
           logMsg           length=$300
    ;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getFileToWS", "%bquote(&sdd_path)", "%bquote(&sdd_version)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The repository object was synchronized to the workspace: &sdd_path..";
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" The repository object could not be synchronized to the workspace: &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_syncfiletoworkspace;
