%* sasdrugdev_updateprojectstate                                                                 *;
%*                                                                                               *;
%* Update the state of a project in the SAS Drug Development repository                          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEPROJECTSTATE(SDD_PATH=sdd-path, SDD_STATE=sdd-state,                        *; 
%* < SDD_COMMENT=sdd-comment, SDD_INCLUDE_ANALYSES=sdd-include-analyses >);                      *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the project to be updated.                           *;
%* @param sdd_state - required - the state to set on the project.                                *;
%*            Values:  DEV | PROD | CLOSED                                                       *;
%* @param sdd_comment - optional - the reason for the state change.                              *;
%* @param sdd_include_analyses - optional - whether project child analyses, if any exist, should *;
%*            have their state updated as well.                                                  *;
%*            Values: 0 | 1                                                                      *;
%*            If no value is supplied, the child analysis states will be updated to the same     *;
%*            state value as supplied for the project.                                           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-05-01 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_updateprojectstate(
  sdd_path=,
  sdd_state=,
  sdd_comment=,
  sdd_include_analyses=1
  ) /des='Update the state of a project.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/ProjectService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("updateState", "%bquote(&sdd_path)", "%bquote(&sdd_state)", "%bquote(&sdd_comment)", 
			     "%bquote(&sdd_include_analyses)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
    logMsg=" The project &sdd_path was updated." ;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot update project &sdd_path." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_updateprojectstate;
