%* sasdrugdev_updateproperties                                                                   *;
%*                                                                                               *;
%* Updates the editable properties of SAS Drug Development repository object using a SAS data    *;
%* set as input.                                                                                 *;
%*                                                                                               *;
%* The output data set from the sasdrugdev_getproperties macro contains the necessary variables  *;
%* and data needed as the input data set for the sasdrugdev_updateproperties macro. Modify the   *;
%* data set with any changes prior to calling sasdrugdev_updateproperties.                       *;
%* - Data in the input data set that do not correspond to a property of the object being updated *;
%*   will be ignored.                                                                            *;
%* - Values specified for properties that are not editable will be ignored.                      *;
%* - An input data value that is the same as the current property value will be ignored and will *;
%*   not result in a property update.  No audit record will be created for the property.         *;
%*                                                                                               *;
%* Organization, project, and analysis leads cannot be updated via the                           *;
%* sasdrugdev_updatepropertiesmacro.  Use the sasdrugdev_updateorglead,                          *;
%* sasdrugdev_updateprojectlead, sasdrugdev_updateanalysislead macros, to update organization,   *;
%* project, and analysis leads, respectively.                                                    *;
%*                                                                                               *;
%* Project and analysis state and state comment cannot be updated via the                        *;
%* sasdrugdev_updateproperties macro.  Use the sasdrugdev_updateprojectstate and                 *;
%* sasdrugdev_updateanalysis state macros for this purpose.                                      *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEPROPERTIES(SDD_PATH=sdd-path, SAS_DSNAME=SAS-data-set);                     *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object in the SAS Drug Development repository.   *;
%* @param sas_dsname - required - the name of a SAS data set containing the property values      *; 
%*            to be set on the repository object specified as libref.dataset.  The data set must *;
%*            contain, at minimum, the variables listed below.  Any additional variables will    *;
%*            be ignored.                                                                        *;
%*            - name: the name of the property to be updated.                                    *;
%*            - value: the value to set on the property.                                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-24  initial coding                                                           *;
%*                                                                                               *;

%macro sasdrugdev_updateproperties(
   sdd_path=,
   sas_dsname=
   ) /des='Updates properties of a SAS Drug Development repository object based on the input data set';

   %****************************************;
   %* Initialize macro variables           *;
   %****************************************;
   %global _sddMsg_
           _sddRC_
   ;
   %local logMsgPrefix
          macroName
          notesOption
          _tempUPDATEPROPS_tempDS_
          tempDsMsg
   ;

   %let _sddRC_ =%str(-999);
   %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

   %let macroName=%sysfunc(lowcase(&SYSMACRONAME));
   %let logMsgPrefix=%str(ERR%str(OR): SAS Drug Development Macro: );   


   %*************************************************************;
   %* Turn off the notes generated for all the pre-processing.  *;
   %* Save original option setting so it can be reset properly. *;
   %*************************************************************;
   %let notesOption=%sysfunc(getoption(notes));
   options nonotes;

   %***************************************************************************;
   %* Cleanup from any previous runs that may have left temp data set behind. *;
   %***************************************************************************;
   %let _tempUPDATEPROPS_tempDS_=%str(__SASMacro_updatepropstemp__);
   %let tempDsMsg=%str(Temporary sorted data set work.&_tempUPDATEPROPS_tempDS_ will not be created.);

   %if (%sysfunc(exist(&_tempUPDATEPROPS_tempDS_)) > 0) %then
   %do;
      %put NOTE: &macroName: Deleting temporary data set &_tempUPDATEPROPS_tempDS_ before processing.;
      proc datasets library=work nolist;
         delete &_tempUPDATEPROPS_tempDS_;
      quit; run;
   %end;

  %***************************************************************************;
  %* Validate the properties data set                                        *;
  %* sets global macro variable _sddRC_=0 if validation successful           *;
  %***************************************************************************;
  %sasdrugdev_validate_sasdataset(callingMacro=&macroName, 
                                  sas_dsn=&sas_dsname,
                                  required_variables=%str(name value)
  );
  %if (&_sddRC_ ne 0) %then
  %do;
     %GOTO PRINT_DSERROR_LOG_MSGS;
  %end;

  %*****************************************************************;
  %* Validate that no duplicate values are present for properties. *;
  %* Order of original data set will be preserved.                 *;
  %*****************************************************************;
  %PUT NOTE: TESTING FOR DUPLICATE PROPERTIES VALUES.;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  proc sort data=&sas_dsname
             out=&_tempUPDATEPROPS_tempDS_;
     by name;
  run;
  data _null_;
     set &_tempUPDATEPROPS_tempDS_;
     by name;
     if (first.name AND NOT(last.name)) then
     do;
	call symput("tempDsMsg", "Temporary sorted data set work.&_tempUPDATEPROPS_tempDS_ was created.");
        call symput("_sddMsg_", "Input data set has duplicate values for property name.");
        STOP;
     end;
     call symput("_sddRC_", "0");
  run;
  %if (&_sddRC_ ne 0) %then
  %do;
     %GOTO PRINT_DSERROR_LOG_MSGS;
  %end;


   option notes;

  %**********************************************;
  %* Process the records                        *;
  %**********************************************;
  data _null_;
    attrib returnCode               length=8;
    attrib message                  length=$200;

    set &_tempUPDATEPROPS_tempDS_ end=eof;

    %***********************************;
    %* Declare the java objects, once  *;
    %***********************************;
    if (_n_ = 1) then
    do;
      declare javaobj props("com/sas/hls/macro/results/SasProperties");
      declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
      declare javaobj results("com/sas/hls/macro/results/Result");

      put "NOTE: SAS Drug Development Macro: * " %sysfunc(lowcase("&SYSMACRONAME"));
      put "NOTE: SAS Drug Development Macro: * Input data set = &sas_dsname";
    end;
    props.callVoidMethod("addProperty", kstrip(name), kstrip(value));

	if (eof) then
	do;

      %***********************************;
      %* Update the properties           *;
      %***********************************;
      srv.callStaticVoidMethod("updateProperties", "%bquote(&sdd_path)", props, results);

      %***********************************;
      %* Retrieve the results            *;
      %***********************************;
      results.callIntMethod("getReturnCode", returnCode);
      results.callStringMethod("getReturnMessage", message);

      %***********************************;
      %* Process the results             *;
      %***********************************;
      if (returnCode ne 0) then
      do;
         logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
         logMsg=" Cannot update object &sdd_path.";
      end;
      else
      do;
         logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
         logMsg=" Updated object &sdd_path.";
      end; 

      %***********************************;
      %* Print messages in log           *;
      %***********************************;
      put;
      put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
      put logMsgPrefix " " logMsg;
      put logMsgPrefix " _sddMsg_= " message ;
      put logMsgPrefix " _sddRC_= " returnCode ;
      put;
      put;

      %***********************************;
      %* Set the macro variables         *;
      %***********************************;
      call symputx("_sddRC_", returnCode);
      call symputx("_sddMsg_", message);
	end;

   run;

   options &notesOption;

   %return;

   %PRINT_DSERROR_LOG_MSGS:
      options &notesOption;
      %put &logMsgPrefix  &macroName ;
      %put &logMsgPrefix _sddRC_= &_sddRC_ ;
      %put &logMsgPrefix _sddMsg_= &_sddMsg_ ;
	  %put &logMsgPrefix &tempDsMsg ;
      %put;

%mend sasdrugdev_updateproperties; 
