%* sasdrugdev_uploadandexpand                                                                    *;
%*                                                                                               *;
%* Uploads and expands the contents of a zip file into the specified folder location in the SAS  *;
%* Drug Development repository.                                                                  *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Failure and Message Handling:                                                                 *;
%* The action status for each file that is being uploaded and each folder that is being created  *;
%* will be printed in the log.                                                                   *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPLOADANDEXPAND(LOCAL_PATH=local-zipfile-path, SDD_PATH=sdd-path                  *;
%* <, SDD_VERSIONING=sdd-versioning, SDD_VERSION=sdd-version, SDD_COMMENT=sdd_comment>);         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param local_path - required - the absolute path and name of the zip file on the local        *;
%*            computer.                                                                          *;
%* @param sdd_path - required - the path of the target folder.                                   *;
%* @param sdd_versioning - optional - indicates whether the new files being created should be    *;
%*            versioned. The default value is 0, which will create a non-versioned file.  A      *;
%*            value of 1 will create a versioned file. The versioning status of existing         *;
%*            files will not be changed.                                                         *;
%*            Values:  0 | 1                                                                     *;
%*            Default: 0                                                                         *;
%* @param sdd_version - optional - the type of version to be created if the new files are to be  *;
%*            versioned. Valid values are MAJOR or MINOR. The default is MINOR. This value is    *;
%*            ignored for non-versioned objects.                                                 *;
%* @param sdd_comment - conditional - the comment for the versioned file being created. This     *;
%*            option is ignored when creating non-versioned files.                               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-03-18  initial code                                                             *;
%*                                                                                               *;

%macro sasdrugdev_uploadandexpand(
  local_path=,
  sdd_path=,
  sdd_versioning=, 
  sdd_version=,
  sdd_comment=
  ) /des='Uploads and expands a zip file into the SAS Drug Development repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8 
           message         length=$200 
           logMsgPrefix    length=$70 
           logMsg          length=$300 
           rowCount        length=8
 
           sasLogFlag      length=$200
           sasLogAction    length=$200
           entryPath       length=$2048
    ;

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/BatchRepositoryService") ;
    declare javaobj results("com/sas/hls/macro/results/SasActionStatusResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("uploadAndExpand", "%bquote(&local_path)", "%bquote(&sdd_path)", "%bquote(&sdd_versioning)", 
         "%bquote(&sdd_version)", "%bquote(&sdd_comment)", results) ;

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getSize", rowCount);

    %***********************************;
    %* Print messages in log           *;
    %* Process the results             *;
    %***********************************;
    put;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Could not attempt the operation to upload and expand the file to target path: &sdd_path.." ;
      put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
      put logMsgPrefix " " logMsg;
      put logMsgPrefix " _sddMsg_= " message ;
      put logMsgPrefix " _sddRC_ = " returnCode ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Attempted the operation to upload and expand the file to target path: &sdd_path.." ;
      put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
      put logMsgPrefix " " logMsg;
      put logMsgPrefix " _sddMsg_= " message ;
    end;

    if (rowCount > 0) then
    do;
       macroNameStamp=strip(lowcase("&SYSMACRONAME")) || ": ";
       do row=0 to rowCount - 1;
         results.callStringMethod("getEntryPath",    row, entryPath);
         results.callStringMethod("getEntryStatus", row, sasLogFlag);
         results.callStringMethod("getEntryAction", row, sasLogAction);
         sasLogFlag   = strip(sasLogFlag)   || ": ";
         sasLogAction = strip(sasLogAction) || ": ";
         put sasLogFlag macroNameStamp sasLogAction entryPath;
       end;
    end;
    put "-" ;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_uploadandexpand;
