%* sasdrugdev_userexists                                                                         *;
%*                                                                                               *;
%* Determines whether a user exists within the system.                                           *;
%*                                                                                               *;
%* The macro variable _sddUserExists_ will be set to 1 if the user exists, 0 if it does not.     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_USEREXISTS(SDD_USERID=sdd-userid);                                                *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddUserExists_ indicates if the user exists.                                         *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the user account to check.                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_userexists(
  sdd_userid=
  ) /des='Is the user defined in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddUserExists_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib exists          length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("exists", "%bquote(&sdd_userid)", results, exists);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine the existence of user '&sdd_userid.'.";
      exists=-1;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (exists) then
      do;
        logMsg=" The user &sdd_userid. was found.";
      end;
      else
      do;
        logMsg=" The user &sdd_userid. was not found.";
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddUserExists_", exists) ;

  run;

%mend sasdrugdev_userexists ;
